Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(9499)

Unified Diff: chrome/installer/test/alternate_version_generator.h

Issue 6338020: Command-line tool to generate a newly versioned mini_installer.exe (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/installer/test/alternate_version_generator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/installer/test/alternate_version_generator.h
===================================================================
--- chrome/installer/test/alternate_version_generator.h (revision 72966)
+++ chrome/installer/test/alternate_version_generator.h (working copy)
@@ -1,4 +1,4 @@
-// Copyright (c) 2010 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
@@ -14,12 +14,22 @@
namespace upgrade_test {
+enum Direction {
+ PREVIOUS_VERSION,
+ NEXT_VERSION
+};
+
// Generates an alternate mini_installer.exe using the one indicated by
-// |original_installer_path|, giving the new one a higher version than the
-// original and placing it in |target_path|. Any previous file at |target_path|
-// is clobbered. Returns true on success.
-bool GenerateNextVersion(const FilePath& original_installer_path,
- const FilePath& target_path);
+// |original_installer_path|, giving the new one a lower or higher version than
+// the original and placing it in |target_path|. Any previous file at
+// |target_path| is clobbered. Returns true on success. |original_version| and
+// |new_version|, when non-NULL, are given the original and new version numbers
+// on success.
+bool GenerateAlternateVersion(const FilePath& original_installer_path,
+ const FilePath& target_path,
+ Direction direction,
+ std::wstring* original_version,
+ std::wstring* new_version);
} // namespace upgrade_test
« no previous file with comments | « no previous file | chrome/installer/test/alternate_version_generator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698